Learn R Programming

plotluck (version 1.1.1)

sample.plotluck: Run plotluck for a randomly generated formula.

Description

sample.plotluck samples a formula as follows:

  • Uniformly draw the number of variables (1-3).

  • For each variable, uniformly choose one of the existing variable types from the data set (numeric, ordered or unordered factor).

  • Uniformly select one of the data frame columns of that type.

Usage

sample.plotluck(data, ...)

Arguments

data

a data frame

...

additional parameters to be passed to plotluck, such as weights and opts.

Value

a ggplot2 object.

See Also

plotluck

Examples

Run this code
# NOT RUN {
set.seed(42)
data(iris)
sample.plotluck(iris)
# }

Run the code above in your browser using DataLab