powered by
plotluck
sample.plotluck samples a formula as follows:
sample.plotluck
Uniformly draw the number of variables (1-3).
For each variable, uniformly choose one of the existing variable types from the data set (numeric, ordered or unordered factor).
Uniformly select one of the data frame columns of that type.
sample.plotluck(data, ...)
a data frame
additional parameters to be passed to plotluck, such as weights and opts.
weights
opts
a ggplot2 object.
# NOT RUN { set.seed(42) data(iris) sample.plotluck(iris) # }
Run the code above in your browser using DataLab